package com.example.readrandomrawdada_kotlin

import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import android.widget.Button
import android.widget.TextView
import android.widget.Toast
import java.nio.charset.Charset
import java.util.*



class MainActivity : AppCompatActivity() {

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_main)

        val btnShow = findViewById<Button>(R.id.btnShow)
        val tvSonnet = findViewById<TextView>(R.id.txtSonnet)
        val rand = Random()
        /*
            use one random number generator over and over (from click to click)
            rather than instantiating a new random number generator with each click
        */
        val min = 15
        val max = 18

        btnShow.setOnClickListener{
            tvSonnet.text = ""

            var sonnet_num = rand.nextInt(max - min + 1) + min
            // use randon number generator to obtain a pseudo-random number between min and max (inclusive)
            val myID = "sonnet_$sonnet_num"
            val resID = resources.getIdentifier(myID, "raw", packageName)

            // http://zetcode.com/kotlin/readfile/
            val input_stream = baseContext.resources.openRawResource(resID)
            var sonnet_text = input_stream.readBytes().toString(Charset.defaultCharset())

            /*
                Kotlin's replace and split methods are overloaded
                the .toRegex() seen below forces kotlin to recognize that
                you are using the version having a signature in which the
                first argument is a regular expression
            */
            //https://stackoverflow.com/questions/18830813/how-can-i-remove-punctuation-from-input-text-in-java
            sonnet_text = sonnet_text.replace("\\n".toRegex(), " ")
            // replace newline characters with spaces
            sonnet_text = sonnet_text.replace("[^a-zA-Z ]".toRegex(), "")
            // eliminate anything that's not a letter or a space
            // a set of characters is denoted by the square brackets
            // within a set of characters the caret means NOT -- so anything that's not a letter or space
            sonnet_text = sonnet_text.toLowerCase()
            var words = sonnet_text.split("\\s+".toRegex()) as MutableList
            // in regular expressions \s means white space \s+ means one or more white-space characters

            //shuffle
            words.shuffle()
            /*
            // old fashioned shuffling
            var j: Int
            var swap: String
            for (i in words.indices) {
                j = rand.nextInt(words.size)
                swap = words[i]
                words[i] = words[j]
                words[j] = swap
            }
           */

            var dada = ""
            for (i in words.indices) {
                dada += words[i]
                if (rand.nextDouble() < 0.90) {
                    dada += " "
                } else {
                    dada += "\n\r"
                }
            }

            tvSonnet.text = dada
        } //end setOnClickListener

    } //end onCreate
} //end MainActivity class